/************************************************************************
 *   IRC - Internet Relay Chat, m_svscmds.c
 *   Copyright (C) 2003 PleXusIRCd Development Team
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 1, or (at your option)
 *   any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *   $Id: m_svscmds.c,v 1.8 2002/09/25 07:43:28 fishwaldo Exp $
 */

#include "stdinc.h"
#include "handlers.h"
#include "client.h"
#include "channel.h"
#include "channel_mode.h"
#include "common.h"		/* FALSE bleah */
#include "ircd.h"
#include "irc_string.h"
#include "numeric.h"
#include "fdlist.h"
#include "s_bsd.h"
#include "s_conf.h"
#include "s_log.h"
#include "s_serv.h"
#include "s_user.h"
#include "send.h"
#include "msg.h"
#include "parse.h"
#include "modules.h"
#include "hash.h"
#include "whowas.h"

static void ms_svshost(struct Client *client_p, struct Client *source_p, int parc, char *parv[]);
static void ms_svsid(struct Client *client_p, struct Client *source_p, int parc, char *parv[]);
static void ms_svsmode(struct Client *client_p, struct Client *source_p, int parc, char *parv[]);

struct Message svshost_msgtab = {
	"SVSHOST", 0, 0, 3, 3, MFLG_SLOW, 0,
	{m_ignore, m_ignore, ms_svshost, m_ignore}
};

struct Message svsid_msgtab = {
	"SVSID", 0, 0, 3, 3, MFLG_SLOW, 0,
	{m_ignore, m_ignore, ms_svsid, m_ignore}
};

struct Message svsmode_msgtab = {
	"SVSMODE", 0, 0, 3, 0, MFLG_SLOW, 0,
	{m_ignore, m_ignore, ms_svsmode, m_ignore}
};

#ifndef STATIC_MODULES
void
_modinit(void)
{
	mod_add_cmd(&svshost_msgtab);
	mod_add_cmd(&svsid_msgtab);
	mod_add_cmd(&svsmode_msgtab);
}

void
_moddeinit(void)
{
	mod_del_cmd(&svshost_msgtab);
	mod_del_cmd(&svsid_msgtab);
	mod_del_cmd(&svsmode_msgtab);
}

const char *_version = "$Revision: 1.91 $";
#endif

/*
 * ms_svshost
 *	Changes the Targets Virtual Hostname, and also sets +h if its not set already on the target
 *      parv[0] = sender prefix
 *      parv[1] = target
 *      parv[2] = new hostname
 */
static void
ms_svshost(struct Client *client_p, struct Client *source_p, int parc, char *parv[])
{
	struct Client *target_p;

	if(parc < 3)
		return;

	if(!IsServer(source_p) && !strcmp(SERVICES, source_p->name)
	    && !strcmp(HOSTSERV, source_p->name))
		return;

	sendto_server(source_p, source_p, NULL, NOCAPS, NOCAPS, LL_ICLIENT,
	    ":%s SVSHOST %s :%s", parv[0], parv[1], parv[2]);

	target_p = find_person(parv[1]);

	if(target_p == NULL)
		return;

	SetHidden(target_p);
	strncpy(target_p->vhost, parv[2], HOSTLEN);
}

/*
 * ms_svsid
 *	Sets/Changes the Services ID for a particular Nickname
 * 	parv[0] = sender prefix
 *	parv[1] = target 
 *	parv[2] = newsvsid
 */
static void
ms_svsid(struct Client *client_p, struct Client *source_p, int parc, char *parv[])
{
	struct Client *target_p;

	if(parc < 3)
		return;

	if(!IsServer(source_p) && !strcmp(SERVICES, source_p->name))
		return;

	sendto_server(source_p, source_p, NULL, NOCAPS, NOCAPS, LL_ICLIENT,
	    ":%s SVSID %s %s", parv[0], parv[1], parv[2]);

	target_p = find_person(parv[1]);

	if(target_p == NULL)
		return;

	target_p->svsid = atol(parv[2]);
}

/*
 * ms_svsmode
 *      Sets/Changes modes for a particular Nickname
 *      parv[0] = sender prefix
 *      parv[1] = target 
 *      parv[2] = modes
 */
static void
ms_svsmode(struct Client *client_p, struct Client *source_p, int parc, char *parv[])
{
	struct Client *target_p;

	if(parc < 3)
		return;

	target_p = find_person(parv[1]);

	if(target_p == NULL)
		return;

	user_mode(client_p, source_p, parc, parv);
}
